// --------------------------------------------------------
// Code generated by Papyrus C++
// --------------------------------------------------------

#ifndef DDICORE_40_PIM_CLASSES_IDENTIFICATION_IDENTIFIABLE_H
#define DDICORE_40_PIM_CLASSES_IDENTIFICATION_IDENTIFIABLE_H

/************************************************************
 Identifiable class header
 ************************************************************/

#include "DDICore_40_PIM/Classes/Identification/Pkg_Identification.h"

#include "DDICore_40_PIM/Classes/RegularExpressions/IsoDateType.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/BasedOnObjectInformation.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/LocalIdFormat.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/RationaleDefinition.h"
#include "PrimitiveTypes/Pkg_PrimitiveTypes.h"

namespace DDICore_40_PIM {
namespace Classes {
namespace Identification {

/************************************************************/
/**
 * Definition
 * ============
 * Used to identify objects for purposes of internal and/or external referencing. Elements of this type are versioned and provide administrative metadata properties. Use for First Order Classes whose content does not need to be discoverable in its own right but needs to be related to multiple classes. 
 * 
 * Examples
 * ==========
 * 
 * 
 * Explanatory notes
 * ===================
 * 
 * 
 * Synonyms
 * ==========
 * 
 * 
 * DDI 3.2 mapping
 * =================
 * 
 * 
 * RDF mapping
 * =============
 * 
 * 
 * GSIM mapping
 * ==============
 */
class Identifiable {
public:

	/**
	 * This is the registered agency code with optional sub-agencies separated by dots. For example, diw.soep, ucl.qss, abs.essg.
	 */
	::PrimitiveTypes::String agency;

	/**
	 * The object/version that this object version is based on.
	 */
	::DDICore_40_PIM::DataTypes::StructuredDataTypes::BasedOnObjectInformation basedOnObject;

	/**
	 * The ID of the object. This must conform to the allowed structure of the DDI Identifier and must be unique within the Agency.
	 */
	::PrimitiveTypes::String id;

	/**
	 * Default value is false. Usually the content of the current version is allowed to change, for example as the contributor is working on the object contents. However, when isPersistent is true, it indicates the there will be no more changes to the current version.
	 */
	::PrimitiveTypes::Boolean isPersistent;

	/**
	 * Default value is false. Usually the combination of agency and id (ignoring different versions) is unique. If isUniversallyUnique is set to true, it indicates that the id itself is universally unique (unique across systems and/or agencies) and therefore the agency part is not required to ensure uniqueness.
	 */
	::PrimitiveTypes::Boolean isUniversallyUnique;

	/**
	 * This is an identifier in a given local context that uniquely references an object, as opposed to the full ddi identifier which has an agency plus the id. For example, localId could be a variable name in a dataset.
	 */
	::DDICore_40_PIM::DataTypes::StructuredDataTypes::LocalIdFormat localId[];

	/**
	 * The version number of the object. The version number is incremented whenever the non-administrative metadata contained by the object changes.
	 */
	::PrimitiveTypes::String version;

	/**
	 * The date and time the object was changed. Supports standard ISO date and datetime formats.
	 */
	::DDICore_40_PIM::Classes::RegularExpressions::IsoDateType versionDate;

	/**
	 * The reason for making this version of the object.
	 */
	::DDICore_40_PIM::DataTypes::StructuredDataTypes::RationaleDefinition versionRationale;

	/**
	 * Contributor who has the ownership and responsibility for the current version.
	 */
	::PrimitiveTypes::String versionResponsibility;

};
/************************************************************/
/* External declarations (package visibility)               */
/************************************************************/

/* Inline functions                                         */

} // of namespace Identification
} // of namespace Classes
} // of namespace DDICore_40_PIM

/************************************************************
 End of Identifiable class header
 ************************************************************/

#endif
