// --------------------------------------------------------
// Code generated by Papyrus C++
// --------------------------------------------------------

#ifndef DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_ANNOTATION_H
#define DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_ANNOTATION_H

/************************************************************
 Annotation class header
 ************************************************************/

#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/Pkg_StructuredDataTypes.h"

#include "DDICore_40_PIM/Classes/RegularExpressions/IsoDateType.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/AgentAssociation.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/AnnotationDate.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/ExternalControlledVocabularyEntry.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/InternationalIdentifier.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/InternationalString.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/ResourceIdentifier.h"
#include "DDICore_40_PIM/DataTypes/XMLSchemaDatatypes/Pkg_XMLSchemaDatatypes.h"
#include "PrimitiveTypes/Pkg_PrimitiveTypes.h"

namespace DDICore_40_PIM {
namespace DataTypes {
namespace StructuredDataTypes {

/************************************************************/
/**
 * Definition
 * ============
 * Provides annotation information on the object to support citation and crediting of the creator(s) of the object.
 * 
 * Examples
 * ==========
 * 
 * 
 * Explanatory notes
 * ===================
 * 
 * 
 * Synonyms
 * ==========
 * 
 * 
 * DDI 3.2 mapping
 * =================
 * r:CitationType
 * 
 * RDF mapping
 * =============
 * 
 * 
 * GSIM mapping
 * ==============
 */
class Annotation {
public:

	/**
	 * An alternative title by which a data collection is commonly referred, or an abbreviation  for the title.
	 */
	InternationalString alternativeTitle[];

	/**
	 * The name of a contributing author or creator, who worked in support of the primary creator given above.
	 */
	AgentAssociation contributor[];

	/**
	 * The copyright statement.
	 */
	InternationalString copyright[];

	/**
	 * Person, corporate body, or agency responsible for the substantive and intellectual content of the described object.
	 */
	AgentAssociation creator[];

	/**
	 * A date associated with the annotated object (not the coverage period). Use typeOfDate to specify the type of date such as Version, Publication, Submitted, Copyrighted, Accepted, etc.
	 */
	AnnotationDate date[];

	/**
	 * An identifier or locator. Contains identifier and Managing agency (ISBN, ISSN, DOI, local archive). Indicates if it is a URI.
	 */
	InternationalIdentifier identifier[];

	/**
	 * The name or identifier of source information for the annotated object.
	 */
	InternationalString informationSource[];

	/**
	 * Language of the intellectual content of the described object. Multiple languages are supported by the structure itself as defined in the transformation to specific bindings. Use language codes supported by xs:language which include the 2 and 3 character and extended structures defined by RFC4646 or its successors. Supports multiple language codes.
	 */
	language languageOfObject[];

	/**
	 * A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.
	 */
	InternationalString provenance[];

	/**
	 * Person or organization responsible for making the resource available in its present form.
	 */
	AgentAssociation publisher[];

	/**
	 * Date the record was created
	 */
	::DDICore_40_PIM::Classes::RegularExpressions::IsoDateType recordCreationDate;

	/**
	 * Date the record was last revised
	 */
	::DDICore_40_PIM::Classes::RegularExpressions::IsoDateType recordLastRevisionDate;

	/**
	 * Provide the identifier, managing agency, and type of resource related to this object. Use to specify related resources similar to Dublin Core isPartOf and hasPart to indicate collection/series membership for objects where there is an identifiable record. If not an identified object use the relationship to ExternalMaterial using a type that indicates a series description.
	 */
	ResourceIdentifier relatedResource[];

	/**
	 * Information about rights held in and over the resource. Typically, rights information includes a statement about various property rights associated with the resource, including intellectual property rights.
	 */
	InternationalString rights[];

	/**
	 * Secondary or explanatory title.
	 */
	InternationalString subTitle[];

	/**
	 * A summary description (abstract) of the annotated object.
	 */
	InternationalString summary;

	/**
	 * Full authoritative title. List any additional titles for this item as AlternativeTitle.
	 */
	InternationalString title;

	/**
	 * Provide the type of the resource. This supports the use of a controlled vocabulary. It should be appropriate to the level of the annotation.
	 */
	ExternalControlledVocabularyEntry typeOfResource[];

	/**
	 * Means of identifying the current version of the annotated object.
	 */
	::PrimitiveTypes::String versionIdentification;

	/**
	 * The agent responsible for the version. May have an associated role.
	 */
	AgentAssociation versioningAgent[];

};
/************************************************************/
/* External declarations (package visibility)               */
/************************************************************/

/* Inline functions                                         */

} // of namespace StructuredDataTypes
} // of namespace DataTypes
} // of namespace DDICore_40_PIM

/************************************************************
 End of Annotation class header
 ************************************************************/

#endif
