// --------------------------------------------------------
// Code generated by Papyrus C++
// --------------------------------------------------------

#ifndef DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_INDIVIDUALNAME_H
#define DDICORE_40_PIM_DATATYPES_STRUCTUREDDATATYPES_INDIVIDUALNAME_H

/************************************************************
 IndividualName class header
 ************************************************************/

#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/Pkg_StructuredDataTypes.h"

#include "DDICore_40_PIM/Classes/Enumerations/Pkg_Enumerations.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/DateRange.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/ExternalControlledVocabularyEntry.h"
#include "DDICore_40_PIM/DataTypes/StructuredDataTypes/InternationalString.h"
#include "PrimitiveTypes/Pkg_PrimitiveTypes.h"

namespace DDICore_40_PIM {
namespace DataTypes {
namespace StructuredDataTypes {

/************************************************************/
/**
 * Definition
 * ============
 * The name of an individual broken out into its component parts of prefix, first/given name, middle name, last/family/surname, and suffix. The preferred compilation of the name parts may also be provided. The legal or formal name of the individual should have the isFormal attribute set to true. The preferred name should be noted with the isPreferred attribute. The attribute sex provides information to assist in the appropriate use of pronouns.
 * 
 * Examples
 * ==========
 * 
 * 
 * Explanatory notes
 * ===================
 * 
 * 
 * Synonyms
 * ==========
 * 
 * 
 * DDI 3.2 mapping
 * =================
 * a:IndividualNameType
 * 
 * RDF mapping
 * =============
 * 
 * 
 * GSIM mapping
 * ==============
 */
class IndividualName {
public:

	/**
	 * An abbreviation or acronym for the name. This may be expressed in multiple languages. It is assumed that if only a single language is provided that it may be used in any of the other languages within which the name itself is expressed.
	 */
	InternationalString abbreviation;

	/**
	 * A name may be specific to a particular context, i.e. common usage, business, social, etc.. Identify the context related to the specified name. Supports the use of an external controlled vocabulary.
	 */
	ExternalControlledVocabularyEntry context;

	/**
	 * Clarifies when the name information is accurate.
	 */
	DateRange effectiveDates;

	/**
	 * First (given) name of the individual
	 */
	::PrimitiveTypes::String firstGiven;

	/**
	 * This provides a means of providing a full name as a single object for display or print such as identification badges etc. For example a person with the name of William Grace for official use may prefer a display name of Bill Grace on a name tag or other informal publication.
	 */
	InternationalString fullName;

	/**
	 * The legal or formal name of the individual should have the isFormal attribute set to true. To avoid confusion only one individual name should have the isFormal attribute set to true. Use the TypeOfIndividualName to further differentiate the type and applied usage when multiple names are provided.
	 */
	::PrimitiveTypes::Boolean isFormal;

	/**
	 * If more than one name for the object is provided, use the isPreferred attribute to indicate which is the preferred name content. All other names should be set to isPreferred="false".
	 */
	::PrimitiveTypes::Boolean isPreferred;

	/**
	 * Last (family) name /surname of the individual
	 */
	::PrimitiveTypes::String lastFamily;

	/**
	 * Middle name or initial of the individual
	 */
	::PrimitiveTypes::String middle[];

	/**
	 * Title that precedes the name of the individual, such as Ms., or Dr.
	 */
	::PrimitiveTypes::String prefix;

	/**
	 * Sex allows for the specification of male, female or neutral. The purpose of providing this information is to assist others in the appropriate use of pronouns when addressing the individual. Note that many countries/languages may offer a neutral pronoun form.
	 */
	::DDICore_40_PIM::Classes::Enumerations::SexSpecificationType sex;

	/**
	 * Title that follows the name of the individual, such as Esq.
	 */
	::PrimitiveTypes::String suffix;

	/**
	 * The type of individual name provided. the use of a controlled vocabulary is strongly recommended. At minimum his should include, e.g. PreviousFormalName, Nickname (or CommonName), Other.
	 */
	ExternalControlledVocabularyEntry typeOfIndividualName;

};
/************************************************************/
/* External declarations (package visibility)               */
/************************************************************/

/* Inline functions                                         */

} // of namespace StructuredDataTypes
} // of namespace DataTypes
} // of namespace DDICore_40_PIM

/************************************************************
 End of IndividualName class header
 ************************************************************/

#endif
